# User Guide

## Getting started
1. [What is QuGradLab](getting_started.md#what-is-qugradlab)
2. [Installation](getting_started.md#installation)

## Running Tests

 - [Running Tests](running_tests.md)

---
[Next](getting_started.md)